==> nextcloud-15.0.5p1.tgz: nextcloud/apps/support/l10n/pl.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Hasło: ",
    "Generating system report failed." : "Generowanie raportu systemowego nie powiodło się.",
    "Subscription notifications" : "Powiadomienia subskrypcji",
    "Could not create folder \"System information\" to store generated report." : "Nie można utworzyć folderu \"Informacje o systemie\" do zachowania wygenerowanego raportu.",
    "Could not create file \"%s\" to store generated report." : "Nie można utworzyć \"%s\" do zachowania wygenerowanego raportu.",
    "Could not share file \"%s\"." : "Nie można udostępnić pliku \"%s\".",
    "Nextcloud Subscription" : "Subskrypcja Nexcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Twój serwer nie ma subskrypcji Nextcloud lub Twoja subskrypcja wygasła.",
    "Your Nextcloud server subscription does not cover your number of users." : "Twoja serwer subskrypcji NextCloud nie obejmuje Twojej liczby użytkowników.",
    "Your Nextcloud Subscription has expired!" : "Twoja subskrypcja Nextcloud wygasła!",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Twój serwer Nextcloud nie jest wspierany przez subskrypcję usługi Nextcloud Enterprise.",
    "Learn more now" : "Dowiedz się więcej",
    "Your Nextcloud server Subscription is over limit" : "Twoja subskrypcja Nextcloud przekracza limit",
    "Dear admin," : "Drogi adminie,",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s jest Twoim menadżerem konta i jest osiągalny mailowo pod adresem %2$s lub telefonicznie pod %3$s.",
    "Thank you," : "Dziękuję,",
    "Your Nextcloud team" : "Twój zespół Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Twoja subskrypcja Nextcloud wygasła",
    "Your Nextcloud server Subscription is expired!" : "Twoja subskrypcja Nextcloud wygasła!",
    "Support" : "Wsparcie",
    "Getting support and help for your Nextcloud" : "Uzyskiwanie wsparcia i pomocy dla Twojego Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikacja wsparcia zapewnia bezpośredni dostęp do pomocy i konsultacji, dedykowane opcje kontaktu z Twoim menedżerem konta i przeglądu subskrypcji dla rozwiązań typu enterprise.",
    "Basic subscription" : "Subskrypcja podstawowa",
    "Standard subscription" : "Subskrypcja standardowa",
    "Premium subscription" : "Subskrypcja premium",
    "Géant subscription" : "Subskrypcja Géant",
    "Silver partner subscription" : "Srebrna subskrypcja dla partnerów",
    "Gold partner subscription" : "Złota subskrypcja dla partnerów",
    "Subscription" : "Subskrypcja",
    "Over subscription limit" : "Przekroczono limit subskrypcji",
    "Valid subscription" : "Subskrypcja poprawna",
    "Expired subscription" : "Subskrypcja wygasła",
    "Subscription key:" : "Klucz subskrypcji: ",
    "_Expires in %n year_::_Expires in %n years_" : ["Wygasa za %n rok","Wygasa za %n lata","Wygasa za %n lat","Wygasa za %n lat"],
    "_Expires in %n month_::_Expires in %n months_" : ["Wygasa za %n miesiąc","Wygasa za %n miesiące","Wygasa za %n miesięcy","Wygasa za %n miesięcy"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Wygasa za %n tydzień","Wygasa za %n tygodnie","Wygasa za %n tygodni","Wygasa za %n tygodni"],
    "_Expires in %n day_::_Expires in %n days_" : ["Wygasa za %n dzień","Wygasa za %n dni","Wygasa za %n dni","Wygasa za %n dni"],
    "Includes support for %s" : "Zawiera wsparcie dla %s",
    "Includes support for %1$s & %2$s" : "Zawiera wsparcie dla %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zawiera wsparcie dla %1$s, %2$s & %3$s",
    "Update subscription key" : "Aktualizuj klucz subskrypcji",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s jest Twoim menadżerem konta. Nie wahaj kontaktować się z nami, jeśli masz pytania dotyczące Twojej subskrypcji.",
    "You can find answers to common question in our portal and also file support requests there." : "Możesz znaleźć odpowiedzi na często zadawane pytania na naszym portalu, gdzie możesz również zgłaszać prośby o wsparcie.",
    "Access Nextcloud portal" : "Przejdź do portalu Nextcloud",
    "System information" : "Informacje systemowe",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Zbieraj informacje o systemie dla przypadków wsparcia. Poniższy przycisk generuje plik tekstowy w folderze \"Informacje systemowe\" i udostępnia go jako publiczny link chroniony hasłem. Link jest ważny przez 2 tygodnie.",
    "Generate system report" : "Generuj raport systemowy",
    "Enterprise subscription recommended" : "Zalecana subskrypcja enterprise",
    "No active enterprise subscription" : "Brak aktywnej subskrypcji enterprise",
    "Unsupported" : "Niewspierane",
    "This Nextcloud server has no Enterprise Subscription." : "Ten serwer Nexcloud nie posiada subskrypcji Enterprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Subskrypcja NextCloud Enterprise pomaga w pełni korzystać z NextCloud, zachować bezpieczeństwo danych i niezawodne działanie serwera.",
    "Advantages" : "Zalety",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Dostęp do wiedzy technicznej deweloperów NextCloud poprzez dokumentację i wsparcie",
    "Access to additional capabilities like Outlook integration, online office and more" : "Dostęp do dodatkowych funkcji takich jak integracja z Outlookiem, biuro online i wiele innych",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Dostęp do wiedzy o skalowalności i możliwościach skalowalności dla aplikacji Pliki i Rozmowy",
    "Optional branding, consulting, architecture advice" : "Opcjonalne doradztwo, porady dotyczące architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Poufna usługa powiadamiania o naruszeniach bezpieczeństwa, migracjach, poprawkach i poradach",
    "Compliance certification, advice and documentation" : "Certyfikacja zgodności, doradztwo i dokumentacja",
    "Get a quote" : "Zdobądź ofertę",
    "More information" : "Więcej informacji",
    "Subscription benefits" : "Korzyści z subskrypcji",
    "Pricing" : "Cennik",
    "Commmunity support" : "Wsparcie społeczności",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud to darmowe oprogramowanie wspierane przez bardzo aktywną społeczność. Zarejestruj się na forum aby zadawać pytania i dyskutuj z innymi.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud wykorzystuje GitHub jako platformę do wspólnej pracy. Możesz tam zgłaszać raporty o błędach.",
    "Chat" : "Czat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Porozmawiaj z nami na naszym kanale IRC #nextcloud na Freenode.",
    "Nextcloud forum" : "Forum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Otwórz chat",
    "Subscription key" : "Klucz subskrypcji",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Jeśli masz aktywną subskrypcję Nextcloud, wpisz klucz subskrypcji tutaj.",
    "Learn more about an enterprise subscription." : "Dowiedz się więcej o subskrypcji enterprise.",
    "Set subscription key" : "Ustaw klucz subskrypcji",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Informacje o subskrypcji nie zostały poprawnie pobrane. Ponowna próba została zaplanowana. Sprawdź później.",
    "The subscription key was invalid." : "Klucz subskrypcji był nieprawidłowy.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Klucz subskrypcji nie mógł zostać zweryfikowany, ponieważ ten serwer nie ma połączenia z Internetem. Skontaktuj się z zespołem pomocy technicznej, aby rozwiązać ten problem.",
    "The subscription key had an invalid format." : "Klucz subskrypcji ma niepoprawny format.",
    "While fetching the subscription information an error happened." : "Wystąpił błąd podczas pobierania informacji o subskrypcji.",
    "News" : "Nowości",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Aby otrzymywać aktualne informacje o tym się co dzieje w Nextcloud, zapisz się do biuletynu i obserwuj nas na naszych kanałach w mediach społecznościowych.",
    "Like our Facebook page" : "Polub nas na Facebook'u",
    "Follow us on Twitter" : "Bądź z nami na Twitterze",
    "Check out our blog" : "Sprawdź nasz blog",
    "Subscribe to our newsletter" : "Subskrybuj nasz newsletter"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");

==> nextcloud-18.0.4.tgz: nextcloud/apps/support/l10n/pl.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Link:",
    "Password:" : "Hasło: ",
    "Generating system report failed." : "Generowanie raportu systemowego nie powiodło się.",
    "Subscription notifications" : "Powiadomienia subskrypcji",
    "Could not create folder \"System information\" to store generated report." : "Nie można utworzyć folderu \"Informacje o systemie\" do zachowania wygenerowanego raportu.",
    "Could not create file \"%s\" to store generated report." : "Nie można utworzyć \"%s\" do zachowania wygenerowanego raportu.",
    "Could not share file \"%s\"." : "Nie można udostępnić pliku \"%s\".",
    "Nextcloud Subscription" : "Subskrypcja Nexcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Twój serwer nie ma subskrypcji Nextcloud lub Twoja subskrypcja wygasła.",
    "Your Nextcloud server subscription does not cover your number of users." : "Subskrypcja serwera Nextcloud nie obejmuje liczby użytkowników.",
    "Your Nextcloud Subscription has expired!" : "Twoja subskrypcja Nextcloud wygasła!",
    "Your server has no Nextcloud Subscription" : "Twój serwer nie ma subskrypcji Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Twój serwer Nextcloud nie jest wspierany przez subskrypcję usługi Nextcloud Enterprise.",
    "Learn more now" : "Dowiedz się więcej",
    "Your Nextcloud server Subscription is over limit" : "Twoja subskrypcja Nextcloud przekracza limit",
    "Dear admin," : "Drogi adminie,",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s jest Twoim menadżerem konta i jest osiągalny mailowo pod adresem %2$s lub telefonicznie pod %3$s.",
    "Thank you," : "Dziękuję,",
    "Your Nextcloud team" : "Twój zespół Nextcloud",
    "Your Nextcloud server Subscription is expired" : "Twoja subskrypcja Nextcloud wygasła",
    "Your Nextcloud server Subscription is expired!" : "Twoja subskrypcja Nextcloud wygasła!",
    "Support" : "Wsparcie",
    "Getting support and help for your Nextcloud" : "Uzyskiwanie wsparcia i pomocy dla Twojego Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "Aplikacja wsparcia zapewnia bezpośredni dostęp do pomocy i konsultacji, dedykowane opcje kontaktu z Twoim menedżerem konta i przeglądu subskrypcji dla rozwiązań typu enterprise.",
    "Basic subscription" : "Subskrypcja podstawowa",
    "Standard subscription" : "Subskrypcja standardowa",
    "Premium subscription" : "Subskrypcja premium",
    "Géant subscription" : "Subskrypcja Géant",
    "Silver partner subscription" : "Srebrna subskrypcja dla partnerów",
    "Gold partner subscription" : "Złota subskrypcja dla partnerów",
    "Subscription" : "Subskrypcja",
    "Over subscription limit" : "Przekroczono limit subskrypcji",
    "Valid subscription" : "Subskrypcja poprawna",
    "Expired subscription" : "Subskrypcja wygasła",
    "Subscription key:" : "Klucz subskrypcji: ",
    "_Expires in %n year_::_Expires in %n years_" : ["Wygasa za %n rok","Wygasa za %n lata","Wygasa za %n lat","Wygasa za %n lat"],
    "_Expires in %n month_::_Expires in %n months_" : ["Wygasa za %n miesiąc","Wygasa za %n miesiące","Wygasa za %n miesięcy","Wygasa za %n miesięcy"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Wygasa za %n tydzień","Wygasa za %n tygodnie","Wygasa za %n tygodni","Wygasa za %n tygodni"],
    "_Expires in %n day_::_Expires in %n days_" : ["Wygasa za %n dzień","Wygasa za %n dni","Wygasa za %n dni","Wygasa za %n dni"],
    "For an unlimited amount of users" : "Dla nieograniczonej liczby użytkowników",
    "_For %n active users_::_For %n active users_" : ["Dla %n aktywnego użytkownika","Dla %n aktywnych użytkowników","Dla %n aktywnych użytkowników","Dla %n aktywnych użytkowników"],
    "_For %n users_::_For %n users_" : ["Dla %n użytkownika","Dla %n użytkowników","Dla %n użytkowników","Dla %n użytkowników"],
    "_currently at %n user_::_currently at %n users_" : ["obecnie na %n użytkownika","obecnie na %n użytkowników","obecnie na %n użytkowników","obecnie na %n użytkowników"],
    "Includes support for %s" : "Zawiera wsparcie dla %s",
    "Includes support for %1$s & %2$s" : "Zawiera wsparcie dla %1$s & %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Zawiera wsparcie dla %1$s, %2$s & %3$s",
    "Update subscription key" : "Aktualizuj klucz subskrypcji",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s jest Twoim menadżerem konta. Nie wahaj kontaktować się z nami, jeśli masz pytania dotyczące Twojej subskrypcji.",
    "You can find answers to common question in our portal and also file support requests there." : "Możesz znaleźć odpowiedzi na często zadawane pytania na naszym portalu, gdzie możesz również zgłaszać prośby o wsparcie.",
    "Access Nextcloud portal" : "Przejdź do portalu Nextcloud",
    "System information" : "Informacje systemowe",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Zbieraj informacje o systemie dla przypadków wsparcia. Poniższy przycisk generuje plik tekstowy w folderze \"Informacje systemowe\" i udostępnia go jako publiczny link chroniony hasłem. Link jest ważny przez 2 tygodnie.",
    "Generate system report" : "Generuj raport systemowy",
    "Enterprise subscription recommended" : "Zalecana subskrypcja enterprise",
    "No active enterprise subscription" : "Brak aktywnej subskrypcji enterprise",
    "Unsupported" : "Niewspierane",
    "This Nextcloud server has no Enterprise Subscription." : "Ten serwer Nexcloud nie posiada subskrypcji Enterprise.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Subskrypcja Enterprise Nextcloud pomaga w pełni wykorzystać możliwości Nextcloud, zapewnić bezpieczeństwo danych i niezawodność działania serwera.",
    "Advantages" : "Zalety",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Dostęp do wiedzy technicznej programistów Nextcloud dzięki dokumentacji i wsparciu",
    "Access to additional capabilities like Outlook integration, online office and more" : "Dostęp do dodatkowych funkcji takich jak integracja z Outlookiem, biuro online i wiele innych",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Dostęp do wiedzy o skalowalności i możliwościach skalowalności dla aplikacji Pliki i Rozmowy",
    "Optional branding, consulting, architecture advice" : "Opcjonalne doradztwo, porady dotyczące architektur",
    "Confidential security notification service, mitigations, patches and advice" : "Poufna usługa powiadamiania o naruszeniach bezpieczeństwa, migracjach, poprawkach i poradach",
    "Compliance certification, advice and documentation" : "Certyfikacja zgodności, doradztwo i dokumentacja",
    "Get a quote" : "Zdobądź ofertę",
    "More information" : "Więcej informacji",
    "Subscription benefits" : "Korzyści z subskrypcji",
    "Pricing" : "Cennik",
    "Commmunity support" : "Wsparcie społeczności",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud to darmowe oprogramowanie wspierane przez bardzo aktywną społeczność. Zarejestruj się na forum aby zadawać pytania i dyskutuj z innymi.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud używa GitHub jako platformy do wspólnej pracy. Możesz bezpośrednio zgłaszać raporty o błędach.",
    "Chat" : "Czat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Porozmawiaj z nami na naszym kanale IRC #nextcloud na Freenode.",
    "Nextcloud forum" : "Forum Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud na GitHub",
    "Open chat" : "Otwórz chat",
    "Subscription key" : "Klucz subskrypcji",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Jeśli masz aktywną subskrypcję Nextcloud, wpisz klucz subskrypcji tutaj.",
    "Learn more about an enterprise subscription." : "Dowiedz się więcej o subskrypcji enterprise.",
    "Set subscription key" : "Ustaw klucz subskrypcji",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Informacje o subskrypcji nie zostały poprawnie pobrane. Ponowna próba została zaplanowana. Sprawdź później.",
    "The subscription key was invalid." : "Klucz subskrypcji był nieprawidłowy.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Klucz subskrypcji nie mógł zostać zweryfikowany, ponieważ ten serwer nie ma połączenia z Internetem. Skontaktuj się z zespołem pomocy technicznej, aby rozwiązać ten problem.",
    "The subscription key had an invalid format." : "Klucz subskrypcji ma niepoprawny format.",
    "While fetching the subscription information an error happened." : "Wystąpił błąd podczas pobierania informacji o subskrypcji.",
    "News" : "Nowości",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Aby otrzymywać aktualne informacje o tym, co dzieje się w Nextcloud, zapisz się do biuletynu i obserwuj nas na naszych kanałach w mediach społecznościowych.",
    "Like our Facebook page" : "Polub nas na Facebook'u",
    "Follow us on Twitter" : "Bądź z nami na Twitterze",
    "Check out our blog" : "Sprawdź nasz blog",
    "Subscribe to our newsletter" : "Subskrybuj nasz newsletter"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
